# UML2DJANGO


# Introduction

# Dependencies
- XML 
https://docs.python.org/3.8/library/xml.etree.elementtree.html#module-xml.etree.ElementTree 
- UML
https://github.com/jgraph/drawio-desktop/releases/tag/v20.3.0

# Features
- model inheritance tree dependencies

# Installation

# Usage

# TODO's
- attributes params
- write relations
- django model type relations
- parse from draw.io xml or plantuml